Description Usage Arguments Value Examples
Build list of matrices with different types of tissues
1 | build.matrix(source.name, assay.data)
|
source.name |
data type |
assay.data |
data from MultiAssayExperiment |
data divided by tissue type, with clinical and source.name assay
1 2 3 4 5 | data('multiAssay')
fpkm.data <- build.matrix('RNASeqFPKM', multiAssay)
fpkm.per.tissue <- fpkm.data$data
fpkm.clinical <- fpkm.data$clinical
names(fpkm.per.tissue)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.